@@ -31,6 +31,7 @@
 #'@param liftpec Threshold point left displacement.
 #'@param rightpec Threshold point right displacement.
 #'@param legend.position Set the position of the legend.
+#'@param lincol Defines the drawing line color.
 #'@importFrom "randomForest" "randomForest"
 #'
 #'
@@ -46,7 +47,7 @@ scidca.randomForest<-function(fit,newdata=NULL,timepoint='median',cmprsk=FALSE,m
                               threshold.text=FALSE,threshold.line=FALSE,nudge_x = 0,nudge_y = 0,
                               threshold.linetype=2,threshold.linewidth = 1.2,threshold.linecol="black",
                               po.text.size=4,po.text.col="black",po.text.fill="white",liftpec=NULL,rightpec=NULL,
-                              legend.position = c(0.85,0.75)) {
+                              legend.position = c(0.85,0.75),lincol=c("#377EB8", "#4DAF4A", "#FF7F00")) {
   if (missing(fit)) stop("fit is missing .")
   fit<-fit;
   if (is.null(modelnames)) {modelnames<-"model"
@@ -62,7 +63,9 @@ scidca.randomForest<-function(fit,newdata=NULL,timepoint='median',cmprsk=FALSE,m
   def_pred<-as.data.frame(def_pred)
   newdata$prob1<-def_pred[,2]
   if (is.character(newdata[,modely])) {newdata[,modely]<-factor(newdata[,modely])}
-  if (is.factor(newdata[,modely])) {newdata[,modely]<-as.numeric(newdata[,modely])-1 }
+  if (is.factor(newdata[,modely])) {
+    newdata[,modely]<-as.numeric(as.character(newdata[,modely]))
+                                 }
   net<-dca(data = newdata, outcome = modely[1], predictors = c("prob1"),xstart = 0,
            xstop = 1,graph=F)
   ########
@@ -70,6 +73,6 @@ scidca.randomForest<-function(fit,newdata=NULL,timepoint='median',cmprsk=FALSE,m
              irrellabel=irrellabel,text.size=text.size,text.col=text.col,colbar=colbar,threshold.text=threshold.text,threshold.line=threshold.line,nudge_x = nudge_x,nudge_y = nudge_y,
              threshold.linetype=threshold.linetype,threshold.linewidth = threshold.linewidth,threshold.linecol=threshold.linecol,
              po.text.size=po.text.size,po.text.col=po.text.col,po.text.fill=po.text.fill,liftpec=liftpec,rightpec=rightpec,
-             legend.position=legend.position)
+             legend.position=legend.position,lincol=lincol)
   p
 }
